@@ -240,6 +240,7 @@ static PyObject *Context_command(ContextObject *self, PyObject *args);
 static PyObject *Context_prnt(ContextObject *self, PyObject *args);
 static PyObject *Context_get_info(ContextObject *self, PyObject *args);
 static PyObject *Context_get_list(ContextObject *self, PyObject *args);
+static PyObject *Context_compare(ContextObject *a, ContextObject *b, int op);
 static PyObject *Context_FromContext(xchat_context *context);
 static PyObject *Context_FromServerAndChannel(char *server, char *channel);
 
@@ -874,6 +875,27 @@ Context_get_list(ContextObject *self, PyObject *args)
 	return ret;
 }
 
+/* needed to make context1 == context2 work */
+static PyObject *
+Context_compare(ContextObject *a, ContextObject *b, int op)
+{
+	PyObject *ret;
+	/* check for == */
+	if (op == Py_EQ)
+		ret = (a->context == b->context ? Py_True : Py_False);
+	/* check for != */
+	else if (op == Py_NE)
+		ret = (a->context != b->context ? Py_True : Py_False);
+	/* only makes sense as == and != */
+	else
+	{
+		PyErr_SetString(PyExc_TypeError, "contexts are either equal or not equal");
+		ret = NULL;
+	}
+
+	return ret;
+}
+
 static PyMethodDef Context_methods[] = {
 	{"set", (PyCFunction) Context_set, METH_NOARGS},
 	{"command", (PyCFunction) Context_command, METH_VARARGS},
@@ -909,7 +931,7 @@ statichere PyTypeObject Context_Type = {
         0,                      /*tp_doc*/
         0,                      /*tp_traverse*/
         0,                      /*tp_clear*/
-        0,                      /*tp_richcompare*/
+        (richcmpfunc)Context_compare,    /*tp_richcompare*/
         0,                      /*tp_weaklistoffset*/
         0,                      /*tp_iter*/
         0,                      /*tp_iternext*/
@@ -1766,7 +1788,8 @@ Module_xchat_get_list(PyObject *self, PyObject *args)
 			}
 			if (attr == NULL)
 				goto error;
-			PyObject_SetAttrString(o, (char*)fld, attr);
+			PyObject_SetAttrString(o, (char*)fld, attr); /* add reference on attr in o */
+			Py_DECREF(attr); /* make o own attr */
 		}
 	}
 	xchat_list_free(ph, list);
