@@ -464,6 +464,7 @@ const struct prefs vars[] = {
 	{"input_balloon_chans", P_OFFINT (input_balloon_chans), TYPE_BOOL},
 	{"input_balloon_hilight", P_OFFINT (input_balloon_hilight), TYPE_BOOL},
 	{"input_balloon_priv", P_OFFINT (input_balloon_priv), TYPE_BOOL},
+	{"input_balloon_time", P_OFFINT (input_balloon_time), TYPE_INT},
 	{"input_beep_chans", P_OFFINT (input_beep_chans), TYPE_BOOL},
 	{"input_beep_hilight", P_OFFINT (input_beep_hilight), TYPE_BOOL},
 	{"input_beep_msg", P_OFFINT (input_beep_priv), TYPE_BOOL},
@@ -674,6 +675,7 @@ load_config (void)
 	prefs.gui_pane_right_size = 100;
 	prefs.mainwindow_save = 1;
 	prefs.bantype = 2;
+	prefs.input_balloon_time = 20;
 	prefs.input_flash_priv = prefs.input_flash_hilight = 1;
 	prefs.input_tray_priv = prefs.input_tray_hilight = 1;
 	prefs.autodccsend = 2;	/* browse mode */
@@ -886,7 +888,6 @@ static void
 set_showval (session *sess, const struct prefs *var, char *tbuf)
 {
 	int len, dots, j;
-	static const char *offon[] = { "OFF", "ON" };
 
 	len = strlen (var->name);
 	memcpy (tbuf, var->name, len);
@@ -909,8 +910,10 @@ set_showval (session *sess, const struct prefs *var, char *tbuf)
 					*((int *) &prefs + var->offset));
 		break;
 	case TYPE_BOOL:
-		sprintf (tbuf + len, "\0033:\017 %s\n", offon[
-					*((int *) &prefs + var->offset)]);
+		if (*((int *) &prefs + var->offset))
+			sprintf (tbuf + len, "\0033:\017 %s\n", "ON");
+		else
+			sprintf (tbuf + len, "\0033:\017 %s\n", "OFF");
 		break;
 	}
 	PrintText (sess, tbuf);
@@ -953,6 +956,7 @@ cmd_set (struct session *sess, char *tbuf, char *word[], char *word_eol[])
 {
 	int wild = FALSE;
 	int or = FALSE;
+	int off = FALSE;
 	int quiet = FALSE;
 	int erase = FALSE;
 	int i = 0, finds = 0, found;
@@ -965,7 +969,15 @@ cmd_set (struct session *sess, char *tbuf, char *word[], char *word_eol[])
 		erase = TRUE;
 	}
 
-	if (strcasecmp (word[idx], "-or") == 0)
+	/* turn a bit OFF */
+	if (strcasecmp (word[idx], "-off") == 0)
+	{
+		idx++;
+		off = TRUE;
+	}
+
+	/* turn a bit ON */
+	if (strcasecmp (word[idx], "-or") == 0 || strcasecmp (word[idx], "-on") == 0)
 	{
 		idx++;
 		or = TRUE;
@@ -1034,6 +1046,8 @@ cmd_set (struct session *sess, char *tbuf, char *word[], char *word_eol[])
 					{
 						if (or)
 							*((int *) &prefs + vars[i].offset) |= atoi (val);
+						else if (off)
+							*((int *) &prefs + vars[i].offset) &= ~(atoi (val));
 						else
 							*((int *) &prefs + vars[i].offset) = atoi (val);
 					}
