@@ -81,19 +81,23 @@ ctcp_check (session *sess, char *nick, char *word[], char *word_eol[],
 }
 
 void
-ctcp_handle (session *sess, char *to, char *nick,
+ctcp_handle (session *sess, char *to, char *nick, char *ip,
 				 char *msg, char *word[], char *word_eol[], int id)
 {
 	char *po;
 	session *chansess;
 	server *serv = sess->server;
 	char outbuf[1024];
+	int ctcp_offset = 2;
+
+	if (serv->have_idmsg && (word[4][1] == '+' || word[4][1] == '-') )
+			ctcp_offset = 3;
 
 	/* consider DCC to be different from other CTCPs */
 	if (!strncasecmp (msg, "DCC", 3))
 	{
 		/* but still let CTCP replies override it */
-		if (!ctcp_check (sess, nick, word, word_eol, word[4] + 2))
+		if (!ctcp_check (sess, nick, word, word_eol, word[4] + ctcp_offset))
 		{
 			if (!ignore_check (word[1], IG_DCC))
 				handle_dcc (sess, nick, word, word_eol);
@@ -118,10 +122,10 @@ ctcp_handle (session *sess, char *to, char *nick,
 		}
 
 		/* but still let CTCP replies override it */
-		if (ctcp_check (sess, nick, word, word_eol, word[4] + 2))
+		if (ctcp_check (sess, nick, word, word_eol, word[4] + ctcp_offset))
 			goto generic;
 
-		inbound_action (sess, to, nick, msg + 7, FALSE, id);
+		inbound_action (sess, to, nick, ip, msg + 7, FALSE, id);
 		return;
 	}
 
@@ -135,7 +139,7 @@ ctcp_handle (session *sess, char *to, char *nick,
 		serv->p_nctcp (serv, nick, outbuf);
 	}
 
-	if (!ctcp_check (sess, nick, word, word_eol, word[4] + 2))
+	if (!ctcp_check (sess, nick, word, word_eol, word[4] + ctcp_offset))
 	{
 		if (!strncasecmp (msg, "SOUND", 5))
 		{
