@@ -16,13 +16,18 @@
 #define closesocket close
 #define set_blocking(sok) fcntl(sok, F_SETFL, 0)
 #define set_nonblocking(sok) fcntl(sok, F_SETFL, O_NONBLOCK)
-#define would_block_again() (errno == EAGAIN || errno == EWOULDBLOCK)
-#define would_block() (errno == EWOULDBLOCK)
+#define would_block() (errno == EAGAIN || errno == EWOULDBLOCK)
 #define sock_error() (errno)
 
 #else
 
+#ifdef USE_IPV6
+#include <winsock2.h>
+#include <ws2tcpip.h>
+#include <tpipv6.h>
+#else
 #include <winsock.h>
+#endif
 
 #define set_blocking(sok)	{ \
 									unsigned long zero = 0; \
@@ -32,8 +37,6 @@
 										unsigned long one = 1; \
 										ioctlsocket (sok, FIONBIO, &one); \
 										}
-#define would_block_again() (WSAGetLastError() == WSAEWOULDBLOCK || \
-									  WSAGetLastError() == WSATRY_AGAIN)
 #define would_block() (WSAGetLastError() == WSAEWOULDBLOCK)
 #define sock_error WSAGetLastError
 
