@@ -104,13 +104,16 @@ net_resolve (netstore * ns, char *hostname, int port, char **real_host)
 		return NULL;
 
 	memset (&ns->addr, 0, sizeof (ns->addr));
-	
+#ifdef LOOKUPD
 	int count = 0;
 	while (ns->ip4_hostent->h_addr_list[count]) count++;
 	memcpy (&ns->addr.sin_addr,
 			ns->ip4_hostent->h_addr_list[RAND_INT(count)],
 			ns->ip4_hostent->h_length);
-	
+#else
+	memcpy (&ns->addr.sin_addr, ns->ip4_hostent->h_addr,
+			  ns->ip4_hostent->h_length);
+#endif
 	ns->addr.sin_port = htons (port);
 	ns->addr.sin_family = AF_INET;
 
@@ -208,6 +211,7 @@ net_resolve (netstore * ns, char *hostname, int port, char **real_host)
 	if (ret != 0)
 		return NULL;
 
+#ifdef LOOKUPD	/* See note about lookupd above the IPv4 version of net_resolve. */
 	struct addrinfo *tmp;
 	int count = 0;
 
@@ -217,6 +221,7 @@ net_resolve (netstore * ns, char *hostname, int port, char **real_host)
 	count = RAND_INT(count);
 	
 	while (count--) ns->ip6_hostent = ns->ip6_hostent->ai_next;
+#endif
 
 	/* find the numeric IP number */
 	ipstring[0] = 0;
