@@ -148,9 +148,14 @@ irc_join_list (server *serv, GSList *channels, GSList *keys)
 		if (klist->data)
 		{
 			add += strlen (klist->data);
-			if (j != 0)
-				add++;	/* comma */
 		}
+		else
+		{
+			add++;	/* 'x' filler */
+		}
+
+		if (j != 0)
+			add++;	/* comma */
 
 		/* too big? dump buffer and start a fresh one */
 		if (len + add > 512)
@@ -187,6 +192,17 @@ irc_join_list (server *serv, GSList *channels, GSList *keys)
 			g_string_append (k, klist->data);
 			j++;
 		}
+		else
+		{
+			add++;
+			if (j != 0)
+			{
+				add++;
+				g_string_append_c (k, ',');
+			}
+			g_string_append_c (k, 'x');
+			j++;
+		}
 
 		len += add;
 
@@ -628,7 +644,7 @@ process_numeric (session * sess, int n,
 
 	case 323:
 		if (!fe_is_chanwindow (sess->server))
-			EMIT_SIGNAL (XP_TE_SERVTEXT, serv->server_session, text, word[1], NULL, NULL, 0);
+			EMIT_SIGNAL (XP_TE_SERVTEXT, serv->server_session, text, word[1], word[2], NULL, 0);
 		else
 			fe_chan_list_end (sess->server);
 		break;
@@ -665,8 +681,9 @@ process_numeric (session * sess, int n,
 		break;
 
 	case 330:
-		EMIT_SIGNAL (XP_TE_WHOIS_AUTH, whois_sess, word[4],
-						 word_eol[6] + 1, word[5], NULL, 0);
+		if (!serv->skip_next_whois)
+			EMIT_SIGNAL (XP_TE_WHOIS_AUTH, whois_sess, word[4],
+							 word_eol[6] + 1, word[5], NULL, 0);
 		break;
 
 	case 332:
@@ -704,7 +721,7 @@ process_numeric (session * sess, int n,
 			/* try to show only user initiated whos */
 			if (!who_sess || !who_sess->doing_who)
 				EMIT_SIGNAL (XP_TE_SERVTEXT, serv->server_session, text, word[1],
-								 NULL, NULL, 0);
+								 word[2], NULL, 0);
 		}
 		break;
 
@@ -727,7 +744,7 @@ process_numeric (session * sess, int n,
 				/* try to show only user initiated whos */
 				if (!who_sess || !who_sess->doing_who)
 					EMIT_SIGNAL (XP_TE_SERVTEXT, serv->server_session, text,
-									 word[1], NULL, NULL, 0);
+									 word[1], word[2], NULL, 0);
 			} else
 				goto def;
 		}
@@ -741,13 +758,13 @@ process_numeric (session * sess, int n,
 			{
 				if (!who_sess->doing_who)
 					EMIT_SIGNAL (XP_TE_SERVTEXT, serv->server_session, text,
-									 word[1], NULL, NULL, 0);
+									 word[1], word[2], NULL, 0);
 				who_sess->doing_who = FALSE;
 			} else
 			{
 				if (!serv->doing_dns)
 					EMIT_SIGNAL (XP_TE_SERVTEXT, serv->server_session, text,
-									 word[1], NULL, NULL, 0);
+									 word[1], word[2], NULL, 0);
 				serv->doing_dns = FALSE;
 			}
 		}
@@ -798,7 +815,7 @@ process_numeric (session * sess, int n,
 
 	case 369:	/* WHOWAS end */
 	case 406:	/* WHOWAS error */
-		EMIT_SIGNAL (XP_TE_SERVTEXT, whois_sess, text, word[1], NULL, NULL, 0);
+		EMIT_SIGNAL (XP_TE_SERVTEXT, whois_sess, text, word[1], word[2], NULL, 0);
 		serv->inside_whois = 0;
 		break;
 
@@ -874,11 +891,11 @@ process_numeric (session * sess, int n,
 			session *realsess = find_channel (serv, word[4]);
 			if (!realsess)
 				realsess = serv->server_session;
-			EMIT_SIGNAL (XP_TE_SERVTEXT, realsess, text, word[1], NULL, NULL, 0);
+			EMIT_SIGNAL (XP_TE_SERVTEXT, realsess, text, word[1], word[2], NULL, 0);
 		} else
 		{
 			EMIT_SIGNAL (XP_TE_SERVTEXT, serv->server_session, text, word[1],
-							 NULL, NULL, 0);
+							 word[2], NULL, 0);
 		}
 	}
 }
@@ -1060,7 +1077,7 @@ process_named_msg (session *sess, char *type, char *word[], char *word_eol[])
 						if (strncasecmp (text, "DCC ", 4) == 0)
 							/* redo this with handle_quotes TRUE */
 							process_data_init (word[1], word_eol[1], word, word_eol, TRUE, FALSE);
-						ctcp_handle (sess, to, nick, text, word, word_eol, id);
+						ctcp_handle (sess, to, nick, ip, text, word, word_eol, id);
 					} else
 					{
 						if (is_channel (serv, to))
@@ -1101,7 +1118,7 @@ garbage:
 /* handle named messages that DON'T start with a ':' */
 
 static void
-process_named_servermsg (session *sess, char *buf, char *word_eol[])
+process_named_servermsg (session *sess, char *buf, char *rawname, char *word_eol[])
 {
 	sess = sess->server->server_session;
 
@@ -1123,7 +1140,8 @@ process_named_servermsg (session *sess, char *buf, char *word_eol[])
 		EMIT_SIGNAL (XP_TE_SERVNOTICE, sess, buf, sess->server->servername, NULL, NULL, 0);
 		return;
 	}
-	EMIT_SIGNAL (XP_TE_SERVTEXT, sess, buf, sess->server->servername, NULL, NULL, 0);
+
+	EMIT_SIGNAL (XP_TE_SERVTEXT, sess, buf, sess->server->servername, rawname, NULL, 0);
 }
 
 /* irc_inline() - 1 single line received from serv */
@@ -1181,7 +1199,7 @@ irc_inline (server *serv, char *buf, int len)
 
 	if (buf[0] != ':')
 	{
-		process_named_servermsg (sess, buf, word_eol);
+		process_named_servermsg (sess, buf, word[0], word_eol);
 		goto xit;
 	}
 
