@@ -49,6 +49,9 @@ static const struct defaultserver def[] =
 	{"2600net",	0},
 	{0,			"irc.2600.net"},
 
+	{"7-indonesia",	0},
+	{0,			"irc.7-indonesia.org"},
+
 	{"AccessIRC",	0},
 	{0,			"irc.accessirc.net"},
 	{0,			"eu.accessirc.net"},
@@ -122,6 +125,9 @@ static const struct defaultserver def[] =
 	{"Beirut", 0},
 	{0,			"irc.beirut.com"},
 
+	{"ChattingAway", 0},
+	{0,			"irc.chattingaway.com"},
+
 	{"ChatJunkies",	0, "#xchat"},
 	{0,			"irc.chatjunkies.org"},
 	{0,			"nl.chatjunkies.org"},
@@ -226,6 +232,9 @@ static const struct defaultserver def[] =
 	{0,				"irc.ca.gamesnet.net"},
 	{0,				"irc.eu.gamesnet.net"},
 
+	{"GeekShed",	0},
+	{0,			"irc.geekshed.net"},
+
 	{"German-Elite",	0},
 	{0,			"dominion.german-elite.net"},
 	{0,			"komatu.german-elite.net"},
@@ -251,9 +260,10 @@ static const struct defaultserver def[] =
 	{0,			"Sunshine.Ca.US.Infinity-IRC.Org"},
 	{0,			"IRC.Infinity-IRC.Org"},*/
 
-	{"insiderZ.DE",	0},
-	{0,			"irc.insiderz.de/6667"},
-	{0,			"irc.insiderz.de/6666"},
+	{"iZ-smart.net",	0},
+	{0,			"irc.iZ-smart.net/6666"},
+	{0,			"irc.iZ-smart.net/6667"},
+	{0,			"irc.iZ-smart.net/6668"},
 
 	{"IrcLink",	0},
 	{0,			"irc.irclink.net"},
@@ -302,6 +312,9 @@ static const struct defaultserver def[] =
 	{"MindForge",	0},
 	{0,			"irc.mindforge.org"},
 
+	{"MintIRC",	0},
+	{0,			"irc.mintirc.net"},
+
 	{"MIXXnet",		0},
 	{0,			"irc.mixxnet.net"},
 
@@ -406,6 +419,9 @@ static const struct defaultserver def[] =
 	{0,			"lisa.rizenet.org"},
 	{0,			"scott.rizenet.org"},
 
+	{"Rizon", 0},
+	{0,			"irc.rizon.net"},
+
 	{"RusNet", 0, 0, "KOI8-R (Cyrillic)"},
 	{0,			"irc.tomsk.net"},
 	{0,			"irc.rinet.ru"},
@@ -418,6 +434,9 @@ static const struct defaultserver def[] =
 	{0,			"irc.eu.scene.org"},
 	{0,			"irc.us.scene.org"},
 
+	{"SeilEn.de",	0},
+	{0,			"irc.seilen.de"},
+
 	{"SlashNET",	0},
 	{0,			"irc.slashnet.org"},
 	{0,			"area51.slashnet.org"},
@@ -452,6 +471,11 @@ static const struct defaultserver def[] =
 	{"TNI3",			0},
 	{0,			"irc.tni3.com"},
 
+	{"TURLINet",			0},
+	{0,			"irc.turli.net"},
+	{0,			"irc.servx.ru"},
+	{0,			"irc.gavnos.ru"},
+
 	{"UnderNet",	0},
 	{0,			"us.undernet.org"},
 	{0,			"eu.undernet.org"},
@@ -472,12 +496,7 @@ static const struct defaultserver def[] =
 	{0,			"irc.fr.worldnet.net"},
 
 	{"Xentonix.net",	0},
-	{0,			"irc.ffm.de.eu.xentonix.net"},
-/*	{0,			"irc.brs.de.eu.xentonix.net"},
-	{0,			"irc.stg.ch.eu.xentonix.net"},
-	{0,			"irc.hou.tx.us.xentonix.net"},*/
-	{0,			"irc.kar.de.eu.xentonix.net"},
-	{0,			"irc.vie.at.eu.xentonix.net"},
+	{0,			"irc.xentonix.net"},
 
 	{"XWorld",	0},
 	{0,			"Buffalo.NY.US.XWorld.org"},
@@ -509,6 +528,8 @@ servlist_connect (session *sess, ircnet *net, gboolean join)
 	list = g_slist_nth (net->servlist, net->selected);
 	if (!list)
 		list = net->servlist;
+	if (!list)
+		return;
 	ircserv = list->data;
 
 	/* incase a protocol switch is added to the servlist gui */
@@ -519,8 +540,11 @@ servlist_connect (session *sess, ircnet *net, gboolean join)
 		sess->willjoinchannel[0] = 0;
 
 		if (net->autojoin)
-			safe_strcpy (sess->willjoinchannel, net->autojoin,
-							 sizeof (sess->willjoinchannel));
+		{
+			if (serv->autojoin)
+				free (serv->autojoin);
+			serv->autojoin = strdup (net->autojoin);
+		}
 	}
 
 	serv->password[0] = 0;
