@@ -25,6 +25,7 @@
 #include <sys/types.h>
 #include <fcntl.h>
 #include <sys/stat.h>
+#include <sys/mman.h>
 
 #include "xchat.h"
 #include <glib/ghash.h>
@@ -216,7 +217,7 @@ scrollback_shrink (session *sess)
 static void
 scrollback_save (session *sess, char *text)
 {
-	char buf[1024];
+	char buf[512 * 4];
 	time_t stamp;
 	int len;
 
@@ -266,10 +267,13 @@ void
 scrollback_load (session *sess)
 {
 	int fh;
-	char buf[1024];
+	char buf[512 * 4];
 	char *text;
 	time_t stamp;
 	int lines;
+	char *map, *end_map;
+	struct stat statbuf;
+	const char *begin, *eol;
 
 	if (sess->text_scrollback == SET_DEFAULT)
 	{
@@ -289,9 +293,32 @@ scrollback_load (session *sess)
 	if (fh == -1)
 		return;
 
+	if (fstat (fh, &statbuf) < 0)
+		return;
+
+	map = mmap (NULL, statbuf.st_size, PROT_READ, MAP_PRIVATE, fh, 0);
+	if (map == MAP_FAILED)
+		return;
+
+	end_map = map + statbuf.st_size;
+	
 	lines = 0;
-	while (waitline (fh, buf, sizeof buf, FALSE) != -1)
+	begin = map;
+	while (begin < end_map)
 	{
+		int n_bytes;
+
+		eol = memchr (begin, '\n', end_map - begin);
+
+		if (!eol)
+			eol = end_map;
+
+		n_bytes = MIN (eol - begin, sizeof (buf) - 1);
+		
+		strncpy (buf, begin, n_bytes);
+
+		buf[n_bytes] = 0;
+		
 		if (buf[0] == 'T')
 		{
 			if (sizeof (time_t) == 4)
@@ -307,6 +334,8 @@ scrollback_load (session *sess)
 			}
 			lines++;
 		}
+
+		begin = eol + 1;
 	}
 
 	sess->scrollwritten = lines;
@@ -320,6 +349,7 @@ scrollback_load (session *sess)
 		/*EMIT_SIGNAL (XP_TE_GENMSG, sess, "*", buf, NULL, NULL, NULL, 0);*/
 	}
 
+	munmap (map, statbuf.st_size);
 	close (fh);
 }
 
@@ -942,6 +972,7 @@ static char * const pevt_chanaction_help[] = {
 	N_("Nickname"),
 	N_("The action"),
 	N_("Mode char"),
+	N_("Identified text"),
 };
 
 static char * const pevt_chanmsg_help[] = {
@@ -1200,6 +1231,12 @@ static char * const pevt_generic_channel_help[] = {
 };
 
 static char * const pevt_servertext_help[] = {
+	N_("Text"),
+	N_("Server Name"),
+	N_("Raw Numeric or Identifier")
+};
+
+static char * const pevt_sslmessage_help[] = {
 	N_("Text"),
 	N_("Server Name")
 };
@@ -1984,7 +2021,8 @@ text_emit (int index, session *sess, char *a, char *b, char *c, char *d)
 	/* ===Private message=== */
 	case XP_TE_PRIVMSG:
 	case XP_TE_DPRIVMSG:
-priv:
+	case XP_TE_PRIVACTION:
+	case XP_TE_DPRIVACTION:
 		if (chanopt_is_set_a (prefs.input_beep_priv, sess->alert_beep))
 			sound_beep (sess);
 		if (chanopt_is_set_a (prefs.input_flash_priv, sess->alert_taskbar))
@@ -2008,8 +2046,6 @@ priv:
 	/* ===Channel message=== */
 	case XP_TE_CHANACTION:
 	case XP_TE_CHANMSG:
-		if (sess->type == SESS_DIALOG)	/* there's no PRIVACTION! */
-			goto priv;
 		if (chanopt_is_set_a (prefs.input_beep_chans, sess->alert_beep))
 			sound_beep (sess);
 		if (chanopt_is_set_a (prefs.input_flash_chans, sess->alert_taskbar))
