@@ -48,6 +48,7 @@
 
 #include "../common/xchat.h"
 #include "../common/fe.h"
+#include "../common/util.h"
 #include "gtkutil.h"
 #include "pixmaps.h"
 
@@ -74,7 +75,7 @@ gtkutil_file_req_destroy (GtkWidget * wid, struct file_req *freq)
 	free (freq);
 }
 
-static int
+static void
 gtkutil_check_file (char *file, struct file_req *freq)
 {
 	struct stat st;
@@ -82,21 +83,7 @@ gtkutil_check_file (char *file, struct file_req *freq)
 
 	path_part (file, last_dir, sizeof (last_dir));
 
-	if (!(freq->flags & FRF_CHOOSEFOLDER) && stat (file, &st) != -1)
-	{
-		if (S_ISDIR (st.st_mode))
-		{
-			char *tmp = malloc (strlen (file) + 2);
-
-			strcpy (tmp, file);
-
-			if (tmp[strlen(tmp)-1] != '/')
-				strcat (tmp, "/");
-			gtk_file_chooser_set_filename (GTK_FILE_CHOOSER (freq->dialog), tmp);
-			free (tmp);
-			return 0;
-		}
-	}
+	/* check if the file is readable or writable */
 	if (freq->flags & FRF_WRITE)
 	{
 		if (access (last_dir, W_OK) == 0)
@@ -115,7 +102,7 @@ gtkutil_check_file (char *file, struct file_req *freq)
 		char *utf8_file;
 		/* convert to UTF8. It might be converted back to locale by
 			server.c's g_convert */
-		utf8_file = g_filename_to_utf8 (file, -1, NULL, NULL, NULL);
+		utf8_file = xchat_filename_to_utf8 (file, -1, NULL, NULL, NULL);
 		if (utf8_file)
 		{
 			freq->callback (freq->userdata, utf8_file);
@@ -131,14 +118,11 @@ gtkutil_check_file (char *file, struct file_req *freq)
 		else
 			fe_message (_("Cannot read that file."), FE_MSG_ERROR);
 	}
-
-	return 1;
 }
 
 static void
 gtkutil_file_req_done (GtkWidget * wid, struct file_req *freq)
 {
-	int kill = 0;
 	GSList *files, *cur;
 	GtkFileChooser *fs = GTK_FILE_CHOOSER (freq->dialog);
 
@@ -147,7 +131,7 @@ gtkutil_file_req_done (GtkWidget * wid, struct file_req *freq)
 		files = cur = gtk_file_chooser_get_filenames (fs);
 		while (cur)
 		{
-			kill |= gtkutil_check_file (cur->data, freq);
+			gtkutil_check_file (cur->data, freq);
 			g_free (cur->data);
 			cur = cur->next;
 		}
@@ -156,13 +140,13 @@ gtkutil_file_req_done (GtkWidget * wid, struct file_req *freq)
 	} else
 	{
 		if (freq->flags & FRF_CHOOSEFOLDER)
-			kill = gtkutil_check_file (gtk_file_chooser_get_current_folder (fs), freq);
+			gtkutil_check_file (gtk_file_chooser_get_current_folder (fs), freq);
 		else
-			kill = gtkutil_check_file (gtk_file_chooser_get_filename (fs), freq);
+			gtkutil_check_file (gtk_file_chooser_get_filename (fs), freq);
 	}
 
-	if (kill)	/* this should call the "destroy" cb, where we free(freq) */
-		gtk_widget_destroy (freq->dialog);
+	/* this should call the "destroy" cb, where we free(freq) */
+	gtk_widget_destroy (freq->dialog);
 }
 
 static void
@@ -195,8 +179,13 @@ gtkutil_file_req (const char *title, void *callback, void *userdata, char *filte
 												GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 												GTK_STOCK_SAVE, GTK_RESPONSE_ACCEPT,
 												NULL);
-		if (filter)	/* filter becomes initial name when saving */
-			gtk_file_chooser_set_current_name (GTK_FILE_CHOOSER (dialog), filter);
+		if (filter && filter[0])	/* filter becomes initial name when saving */
+		{
+			char temp[1024];
+			path_part (filter, temp, sizeof (temp));
+			gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (dialog), temp);
+			gtk_file_chooser_set_current_name (GTK_FILE_CHOOSER (dialog), file_part (filter));
+		}
 #if GTK_CHECK_VERSION(2,8,0)
 		if (!(flags & FRF_NOASKOVERWRITE))
 			gtk_file_chooser_set_do_overwrite_confirmation (GTK_FILE_CHOOSER (dialog), TRUE);
@@ -220,6 +209,11 @@ gtkutil_file_req (const char *title, void *callback, void *userdata, char *filte
 		gtk_file_chooser_set_action (GTK_FILE_CHOOSER (dialog), GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER);
 		gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (dialog), filter);
 	}
+	else
+	{
+		if (filter && (flags & FRF_FILTERISINITIAL))
+			gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (dialog), filter);
+	}
 
 	freq = malloc (sizeof (struct file_req));
 	freq->dialog = dialog;
@@ -382,7 +376,9 @@ gtkutil_button (GtkWidget *box, char *stock, char *tip, void *callback,
 	{
 		gtk_button_set_label (GTK_BUTTON (wid), labeltext);
 		gtk_button_set_image (GTK_BUTTON (wid), gtk_image_new_from_stock (stock, GTK_ICON_SIZE_MENU));
-		gtk_container_add (GTK_CONTAINER (box), wid);
+		gtk_button_set_use_underline (GTK_BUTTON (wid), TRUE);
+		if (box)
+			gtk_container_add (GTK_CONTAINER (box), wid);
 	}
 	else
 	{
@@ -557,17 +553,10 @@ gtkutil_copy_to_clipboard (GtkWidget *widget, GdkAtom selection,
 	win = gtk_widget_get_toplevel (GTK_WIDGET (widget));
 	if (GTK_WIDGET_TOPLEVEL (win))
 	{
-		glong len = g_utf8_strlen (str, -1);
+		int len = strlen (str);
 
 		if (selection)
 		{
-#if (GTK_MAJOR_VERSION == 2) && (GTK_MINOR_VERSION == 0)
-			gtk_clipboard_set_text (gtk_clipboard_get (selection), str, len);
-		} else
-		{
-			clip = gtk_clipboard_get (GDK_SELECTION_PRIMARY);
-			clip2 = gtk_clipboard_get (GDK_SELECTION_CLIPBOARD);
-#else
 			clip = gtk_widget_get_clipboard (win, selection);
 			gtk_clipboard_set_text (clip, str, len);
 		} else
@@ -575,7 +564,6 @@ gtkutil_copy_to_clipboard (GtkWidget *widget, GdkAtom selection,
 			/* copy to both primary X selection and clipboard */
 			clip = gtk_widget_get_clipboard (win, GDK_SELECTION_PRIMARY);
 			clip2 = gtk_widget_get_clipboard (win, GDK_SELECTION_CLIPBOARD);
-#endif
 			gtk_clipboard_set_text (clip, str, len);
 			gtk_clipboard_set_text (clip2, str, len);
 		}
