@@ -1,4 +1,4 @@
 int tray_plugin_init (void *, char **, char **, char **, char *);
 int tray_plugin_deinit (void *);
-gboolean tray_toggle_visibility (void);
+gboolean tray_toggle_visibility (gboolean force_hide);
 void tray_apply_setup (void);
