@@ -16,8 +16,6 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
  */
 
-#define GTK_DISABLE_DEPRECATED
-
 #include <string.h>
 #include <stdio.h>
 #include <stdlib.h>
@@ -41,6 +39,7 @@ typedef struct session xchat_context;
 #include "../common/plugin.h"
 #include "../common/util.h"
 #include "../common/outbound.h"
+#include "../common/fe.h"
 #include "../common/xchatc.h"
 #include "gtkutil.h"
 
@@ -182,7 +181,7 @@ plugingui_unload (GtkWidget * wid, gpointer unused)
 #endif
 	{
 		if (plugin_kill (modname, FALSE) == 2)
-			gtkutil_simpledialog (_("That plugin is refusing to unload.\n"));
+			fe_message (_("That plugin is refusing to unload.\n"), FE_MSG_ERROR);
 	} else
 	{
 		/* let python.so or perl.so handle it */
@@ -219,7 +218,7 @@ plugingui_open (void)
 	action_area = GTK_DIALOG (plugin_window)->action_area;
 	gtk_container_set_border_width (GTK_CONTAINER (vbox), 4);
 	gtk_window_set_position (GTK_WINDOW (plugin_window), GTK_WIN_POS_CENTER);
-	gtk_window_set_title (GTK_WINDOW (plugin_window), _("X-Chat: Plugins and Scripts"));
+	gtk_window_set_title (GTK_WINDOW (plugin_window), _("XChat: Plugins and Scripts"));
 
 	view = plugingui_treeview_new (vbox);
 	g_object_set_data (G_OBJECT (plugin_window), "view", view);
