@@ -797,7 +797,7 @@ servlist_autojoineditok_cb (GtkWidget *button, GtkWidget *tree)
 	autojoin = joinlist_merge (channels, keys);
 	if (autojoin)
 	{
-		if (selected_net)
+		if (edit_win && selected_net)
 			gtk_entry_set_text (GTK_ENTRY (edit_entry_join), autojoin);
 		else
 		{
@@ -810,6 +810,9 @@ servlist_autojoineditok_cb (GtkWidget *button, GtkWidget *tree)
 
 	/* this does g_free too */
 	joinlist_free (channels, keys);
+
+	if (fav_add_net)
+		servlist_save ();
 }
 
 void
@@ -838,7 +841,7 @@ servlist_autojoinedit (ircnet *net, char *channel, gboolean add)
 	GSList *clist, *klist;
 	GtkTreeIter iter;
 
-	if (selected_net)
+	if (edit_win && selected_net)
 		/* update net->autojoin */
 		servlist_edit_update (selected_net);
 
@@ -847,7 +850,8 @@ servlist_autojoinedit (ircnet *net, char *channel, gboolean add)
 	gtk_window_set_title (GTK_WINDOW (win), _("XChat: Favorite Channels (Auto-Join List)"));
 	gtk_window_set_default_size (GTK_WINDOW (win), 354, 256);
 	gtk_window_set_position (GTK_WINDOW (win), GTK_WIN_POS_MOUSE);
-	gtk_window_set_transient_for (GTK_WINDOW (win), GTK_WINDOW (edit_win));
+	if (edit_win)
+		gtk_window_set_transient_for (GTK_WINDOW (win), GTK_WINDOW (edit_win));
 	gtk_window_set_modal (GTK_WINDOW (win), TRUE);
 	gtk_window_set_type_hint (GTK_WINDOW (win), GDK_WINDOW_TYPE_HINT_DIALOG);
 	gtk_window_set_role (GTK_WINDOW (win), "editserv");
@@ -1014,10 +1018,37 @@ servlist_connect_cb (GtkWidget *button, gpointer userdata)
 		return;
 	}
 
-	if (!is_session (servlist_sess))
-		servlist_sess = NULL;
-	else if (servlist_sess->server->connected)
-		servlist_sess = NULL;
+ 	if (!is_session (servlist_sess))
+		servlist_sess = NULL;	/* open a new one */
+
+	{
+		GSList *list;
+		session *sess;
+		session *chosen = servlist_sess;
+
+		servlist_sess = NULL;	/* open a new one */
+
+		for (list = sess_list; list; list = list->next)
+		{
+			sess = list->data;
+			if (sess->server->network == selected_net)
+			{
+				servlist_sess = sess;
+				if (sess->server->connected)
+					servlist_sess = NULL;	/* open a new one */
+				break;
+			}
+		}
+
+		/* use the chosen one, if it's empty */
+		if (!servlist_sess &&
+			  chosen &&
+			 !chosen->server->connected &&
+			  chosen->server->server_session->channel[0] == 0)
+		{
+			servlist_sess = chosen;
+		}
+	}
 
 	servlist_connect (servlist_sess, selected_net, TRUE);
 
